==> google-cloud-sdk-265.0.0.tgz: google-cloud-sdk/lib/surface/firebase/test/android/versions/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2017 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The 'gcloud firebase test android versions describe' command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.firebase.test import exceptions
from googlecloudsdk.api_lib.firebase.test import util
from googlecloudsdk.calliope import base


class Describe(base.DescribeCommand):
  """Describe an Android OS version."""

  @staticmethod
  def Args(parser):
    """Method called by Calliope to register flags for this command.

    Args:
      parser: An argparse parser used to add arguments that follow this
          command in the CLI. Positional arguments are allowed.
    """
    # Positional arg
    parser.add_argument(
        'version_id',
        help='The version ID to describe, found using $ {parent_command} list.')

  def Run(self, args):
    """Run the 'gcloud firebase test android versions describe' command.

    Args:
      args: an argparse namespace. All the arguments that were provided to this
        command invocation (i.e. group and command arguments combined).

    Returns:
      The testing_v1_messages.AndroidVersion object to describe.
    """
    catalog = util.GetAndroidCatalog(self.context)
    for version in catalog.versions:
      if version.id == args.version_id:
        return version
    raise exceptions.VersionNotFoundError(args.version_id)

==> google-cloud-sdk-549.0.1.tgz: google-cloud-sdk/lib/surface/firebase/test/android/versions/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2017 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The 'gcloud firebase test android versions describe' command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.firebase.test import exceptions
from googlecloudsdk.api_lib.firebase.test import util
from googlecloudsdk.calliope import base


DETAILED_HELP = {
    'EXAMPLES': """
    To see attributes of the Android OS version 'my-version', run:

      $ {command} my-version
    """,
}


class Describe(base.DescribeCommand):
  """Describe an Android OS version."""

  detailed_help = {
      'DESCRIPTION': 'Describe an Android OS version.',
      'EXAMPLES': """To describe an Android OS version available for testing,
run:

  {command} Q

To describe an Android OS version available for testing in JSON format,
run:

  {command} Q --format=json
"""
  }

  @staticmethod
  def Args(parser):
    """Method called by Calliope to register flags for this command.

    Args:
      parser: An argparse parser used to add arguments that follow this
          command in the CLI. Positional arguments are allowed.
    """
    # Positional arg
    parser.add_argument(
        'version_id',
        help='The version ID to describe, found using $ {parent_command} list.')

  def Run(self, args):
    """Run the 'gcloud firebase test android versions describe' command.

    Args:
      args: an argparse namespace. All the arguments that were provided to this
        command invocation (i.e. group and command arguments combined).

    Returns:
      The testing_v1_messages.AndroidVersion object to describe.
    """
    catalog = util.GetAndroidCatalog(self.context)
    for version in catalog.versions:
      if version.id == args.version_id:
        return version
    raise exceptions.VersionNotFoundError(args.version_id)


Describe.detailed_help = DETAILED_HELP
